| Title: | Implements Queue, PriorityQueue and Stack Classes |
|---|---|
| Description: | Provides three classes: Queue, PriorityQueue and Stack. Queue is just a "plain vanilla" FIFO queue; PriorityQueue orders items according to priority. Stack implements LIFO. |
| Authors: | Andrew Collier [aut, cre] |
| Maintainer: | Andrew Collier <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.5 |
| Built: | 2026-05-29 12:51:10 UTC |
| Source: | https://github.com/datawookie/liqueuer |
Derived from the Queue class.
dataInitial data to populate the queue.
prioritiesNumeric queue priorities.
prioritiseFunction to calculate priorities from items.
pop(N = 1)Removes and returns head of queue (or raises error if queue is empty). N is number of items to pop.
push(item)Inserts element at back of the queue.
Queue-class for information on base class.
A Queue reference class
dataInitial data to populate the queue.
peek(pos = c(1), as.list = FALSE)Returns (but does not remove) specified positions in queue (or NULL if any one of them is not available). The as.list argument will cause a list to be returned even if only one element requested.
poll()Removes and returns head of queue (or NULL if queue is empty).
pop(N = 1)Removes and returns head of queue (or raises error if queue is empty). N is number of items to pop.
push(item)Inserts element at back of the queue.
size()Returns the number of items in the queue.
queue <- Queue$new() queue$push("one") queue$push(2) queue$push("three") queue$size() queue$pop() queue$poll()queue <- Queue$new() queue$push("one") queue$push(2) queue$push("three") queue$size() queue$pop() queue$poll()
Derived from the Queue class.
dataInitial data to populate the stack.
push(item)Inserts element at back of the queue.
Queue-class for information on base class.